===============================================
 oslo.db -- OpenStack Database Pattern Library
===============================================

The oslo.db (database) handling library, provides database
connectivity to different database backends and various other helper
utils.

.. toctree::
   :maxdepth: 2

   install/index
   contributor/index
   user/index
   reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
